#!/usr/local/bin/perl -w

#consensus.pl - version 0.2


# Copyright (C) 2001-2002.
# Ted Perdersen, University Of Minnesota, Duluth.
# tpederse@d.umn.edu
# Nitin Varma, University Of Minnesota, Duluth.
# varm0003@d.umn.edu


# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# ----------------------------------------------------------------------------
#                             Main Program
# ----------------------------------------------------------------------------

# package required for command line options
use Getopt::Long;

GetOptions("version", "help","content");

# Now strip the command line options

if ( defined $opt_help ) { $help = $opt_help; }
else                     { $help = 0; }


if ( defined $opt_version ) { $version = $opt_version; }
else                        { $version = 0; } 


# if asked for help, print the help and exit.  
if ( $help )
{
    &printHelp();
    exit;
}

# if asked for version, print the version number and exit
if ( $version )
{
    &printVersion();
    exit;
}

if($#ARGV < 2)
{
    &printHelp();
    exit;
}

#depending on the number of annotators decides the cutoff of majority
$majority_number{1} = 1;
$majority_number{2} = 2;
$majority_number{3} = 2;
$majority_number{4} = 3;
$majority_number{5} = 3;

#input and output directories
$inpath = shift;
$outpath = shift;

#checks if the directory output directory exists
if(-e $outpath)
{
    print "\nDirectory exists!!! overwrite ??";
    $ans = <STDIN>;
    chomp $ans;
    $ans = uc $ans;
    if($ans eq "Y")
    {
	system "/bin/rm -rf $outpath";
    }
    else
    {
	exit;
    }
}

#commad to make the directory
system "mkdir $outpath";     

$majority = $majority_number{$#ARGV+1};

#prepares a string of annotator numbers given on command-line and also decides on
#the start and end verses for the combinatio.
for($i=0;$i<=$#ARGV;$i++)
{
    $string .= $ARGV[$i];
}

#checks for invlalid combinations of annotators

if($string =~ m/[089]/)
{
    print "\nERROR !!!Annotator numbers can be only between 1-7 both inclusive\n";
    &printHelp();
    exit;
}

if($string =~ m/[45]/)
{
    if($string =~ m/[67]/)
    {
	print "\nNot possible";
        exit;
    }
}
if($string =~ m/[67]/)
{
    $start = 11;
    $end = 25;
}

elsif($string =~ m/[45]/)
{
    $start = 1;
    $end = 10;
}

else
{
    $start = 1;
    $end = 25;
}


for($i=$start;$i<=$end;$i++)
{
    
    for($j=0;$j<10;$j++)
    {

        for($count = 0;$count<=$#ARGV;$count++)
	{
	    $anno = "A".$ARGV[$count];
	    $fullpath = $inpath."/".$anno;
            if(defined($opt_content))
	    {
		$file = $fullpath."/"."samp".$i."."."SentPair"."$j"."."."open";
	    }
	    else
	    {
		$file = $fullpath."/"."samp".$i."."."SentPair"."$j";
	    }

	    open(FILE, $file) || die "FILE NOT FOUND !!! Error opening $file\n";

#reads the samp.* files and if two english words are translated to same word
# concatenates the word positions.
	    while($line = <FILE>)
	    {
                
		$line = &removeSpaces($line);
		($word1, $word2) = split(/ /, $line);
		$array_hash[$count]{$word1} .= $word2." ";
                
	    }
	    close(FILE);
	}
	
#once the above is done for given combination of annotatores it preapres a common 
#hash so that we have number of votes for each token
 	for($annotator=0;$annotator<=$#ARGV;$annotator++)
	{
	    $annotator_hash = $array_hash[$annotator];
            &makeHash($annotator_hash, \%common_hash);
	}
	
        if(defined($opt_content))
	{
	    $fullpath = $outpath."/"."samp".$i."."."SentPair".$j."."."open";
	}
	else
	{
	    $fullpath = $outpath."/"."samp".$i."."."SentPair".$j;
	}
	open(FILE,">$fullpath");

#prints the one above or equal to majotiry
	foreach $word_pair (keys %common_hash)
	{
	    if($common_hash{$word_pair}>= $majority)
	    {
                delete($common_hash{$word_pair});
		print FILE "$word_pair\n";
	    }
	}


	
	close(FILE);
        @array_hash = ();
        %common_hash = ();

    }
}
    

# ---------------------------------------------------------------------------
#                                 USER DEFINED FUNCTIONS
# ---------------------------------------------------------------------------

# prints what are the command line options for the program and explain what
# input is required by different arguments
sub printHelp{

    &printUsage();
    print "OPTIONS:";
    print "\n  --content      to build the gold data using *.open files";
    print "\n                 i.e only for cotent words(by default uses all words)";  
    print "\n\n  --version     Prints the version number";
    print "\n\n  --help        Prints the help message\n";
}



# prints the usage of the program.
sub printUsage{
     print "\nUsage:consensus.pl [{[--content] BLINKER_DIR OUT_DIR ANNOTATOR_LIST |--help|--version}]\n";
    print "BLINKER_DIR    - path of directory where blinker data exists";
    print "\nOUT_DIR        - directory to be created for storing consensus files";
    print "\nANNOTATOR_LIST - annotator number(1-7) for that should used for creating gold data";
    print "\n                 1 for A1, 2 for A2 ..... 7 for A7\n\n";

}




# prints the version number and copyright information.
sub printVersion{

    print "consensus.pl -  Version 0.2\n";
    print "Copyright (C) 2001-2002, Ted Pedersen & Nitin Varma\n";

}



#function removes white spaces
sub removeSpaces{
    my $line = $_[0];
    $line =~ s/^\s+//;
    $line =~ s/\s+$//;
    $line =~ s/\s+/ /;
    $line =~ s/\n+//;
    return($line);
}


#function which takes by an annotator one by and one and prepares
#a common hash
sub makeHash{
    my $annotator_ref = $_[0];
    my $common_ref = $_[1];
    
    foreach $word(keys %$annotator_ref)
    {
	$value = $annotator_ref->{$word};
        $value = &removeSpaces($value);
        $word = &removeSpaces($word);
        $pair = $word." ". $value;
        $common_ref->{$pair}++;
    }
}

