#!/usr/local/bin/perl -w

#script.pl - version 0.2


# Copyright (C) 2001-2002.
# Ted Perdersen, University Of Minnesota, Duluth.
# tpederse@d.umn.edu
# Nitin Varma, University Of Minnesota, Duluth.
# varm0003@d.umn.edu


# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ----------------------------------------------------------------------------
#                             Main Program
# ----------------------------------------------------------------------------


# package required for command line options
use Getopt::Long;

GetOptions("version", "help","content");

if ( defined $opt_help ) { $help = $opt_help; }
else                     { $help = 0; }


if ( defined $opt_version ) { $version = $opt_version; }
else                        { $version = 0; } 

if(defined $opt_content){ $string = "--content "; }


# if asked for help, print the help and exit.  
if ( $help )
{
    &printHelp();
    exit;
}

# if asked for version, print the version number and exit
if ( $version )
{
    &printVersion();
    exit;
}

if($#ARGV < 2)
{
    &printHelp();
    exit;
}



$BLINKER = shift;
$dir = shift;

if(defined $opt_content)
{
    $string = "--content ";
}
for($i=0;$i<=$#ARGV;$i++)
{
    $string .= " ".$ARGV[$i];
}
print "Running consensus.pl\n";
system("perl consensus.pl $BLINKER $dir $string");

print "\nRunning token.pl\n";
system ("perl token.pl English.txt French.txt $dir > GOLD.TOKEN");

print "\nRunning type.pl\n";
system ("perl type.pl GOLD.TOKEN GOLD.TYPE");

print "\nRunning filter.pl\n";
system ("perl filter.pl GOLD.TYPE SINGLE.TYPE MULTI.TYPE");

# ---------------------------------------------------------------------------
#                                 USER DEFINED FUNCTIONS
# ---------------------------------------------------------------------------

sub printHelp{

    &printUsage();
    print "OPTIONS:";
    print "\n  --content      to build the gold data using *.open files";
    print "\n                 i.e only for cotent words(by default uses all words)";  
    print "\n\n  --version     Prints the version number";
    print "\n\n  --help        Prints the help message\n";
}




# prints the usage of the program.
sub printUsage{
     print "\nUsage:script.pl [{[--content] BLINKER_DIR OUT_DIR ANNOTATOR_LIST |--help|--version}]\n";
    print "BLINKER_DIR    - path of directory where blinker data exists";
    print "\nOUT_DIR        - directory to be created for storing consensus files";
    print "\nANNOTATOR_LIST - annotator number for that should used for creating gold data";
    print "\n                 1 for A1, 2 for A2 ..... 7 for A7\n\n";

}




# prints the version number and copyright information.
sub printVersion{

    print "script.pl -  Version 0.2\n";
    print "Copyright (C) 2001-2002, Ted Pedersen & Nitin Varma\n";

}
