#!/usr/local/bin/perl -w

#token.pl - version 0.2

# For each verse this program takes the annotations done by different
# annotatotrs and finds the annotation for each word in the verse. The
# criteria for choosing the annotation suugested by majority of the
# annotators. In case of clash, iy randomly selects any one.

# Copyright (C) 2001-2002.
# Ted Perdersen, University Of Minnesota, Duluth.
# tpederse@d.umn.edu
# Nitin Varma, University Of Minnesota, Duluth.
# varm0003@d.umn.edu


# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# ----------------------------------------------------------------------------
#                             Main Program
# ----------------------------------------------------------------------------

# package required for command line options
use Getopt::Long;

GetOptions("version", "help");

# Now strip the command line options

if ( defined $opt_help ) { $help = $opt_help; }
else                     { $help = 0; }


if ( defined $opt_version ) { $version = $opt_version; }
else                        { $version = 0; } 


# if asked for help, print the help and exit.  
if ( $help )
{
    &printHelp();
    exit;
}

# if asked for version, print the version number and exit
if ( $version )
{
    &printVersion();
    exit;
}

# check if all 3 non-optional arguments are provided or not.
if($#ARGV < 2 )
{
    
    &printUsage();
    exit;
}

$eng_file = shift;
$french_file = shift;
$directory = shift;

opendir(DIR,$directory) || die "\nDIRECTORY NOT FOUND !! ERROR opening $directory\n";

@files = grep { $_ ne '.' and $_ ne '..'} readdir DIR;
closedir DIR;

if($files[0] =~ m/open/)
{
    $content_flag = 1;
}
else
{
    $content_flag = 0;
}

open(FILE,$eng_file) || die "\nFILE NOT FOUND !! ERROR opening $eng_file\n";

for($i=1;$i<=25;$i++)
{
    for($j=0;$j<10;$j++)
    {
        if($content_flag == 1)
	{
	    $key = "samp".$i."."."SentPair".$j."."."open";
	}
	else
	{
	    $key = "samp".$i."."."SentPair".$j;
	}
	$line = <FILE>;
        $line = &removeSpaces($line); 
        $eng_hash{$key} = $line;
    }
} 
close(FILE);
open(FILE,$french_file)|| die "\nFILE NOT FOUND !! ERROR opening $french_file\n"; ;
for($i=1;$i<=25;$i++)
{
    for($j=0;$j<10;$j++)
    {
        if($content_flag == 1)
	{
	    $key = "samp".$i."."."SentPair".$j."."."open";
	}
	else
	{
	    $key = "samp".$i."."."SentPair".$j;
	}
	$line = <FILE>;
        $line = &removeSpaces($line); 
        $french_hash{$key} = $line;
    }
} 
close(FILE);


foreach $filename (@files)
{
   
    $filepath = $directory."/".$filename;    
    open(FILE, $filepath) ||die "\nFILE NOT FOUND !! ERROR opening $filepath\n" ;
    while($line = <FILE>)
    {
	$line = &removeSpaces($line);
	($left, @temp) = split(/ /,$line);
	for($j=0;$j<=$#temp;$j++)
	{
	    $right .= $temp[$j]." ";
	}
        $reverse_hash{$right} .= $left." ";
        @temp = ();
        undef($right);
    }
  
  
    $eng_line = $eng_hash{$filename};
    $eng_line = lc($eng_line);
    @eng_words = split(/ /, $eng_line);

    $french_line = $french_hash{$filename};
    $french_line = lc($french_line);
    @french_words = split(/ /, $french_line);
   
    foreach $right(keys %reverse_hash)
    {
	$left = $reverse_hash{$right};
        $left = &removeSpaces($left);
        $right = &removeSpaces($right);
       	@leftarray = split(/ /,$left);
        @rightarray = split(/ /,$right);
        #print "\nleft = $left";
        #print "\nright = $right";
        #print "\nleft array size = $#leftarray";
        #print "\nright array size = $#rightarray";
        for($i=0;$i<=$#leftarray;$i++)
	{   
            #print "\nl=$i";
            #<STDIN>;
	    $eng_side .= $eng_words[$leftarray[$i]-1]." ";
            if($leftarray[$i] eq 0)
	    {
		$eng_side = "NULL";
	    }
	}
        for($i=0;$i<=$#rightarray;$i++)
	{
	    #$print "\nr=$i";
            #<STDIN>;
       	    $french_side .= $french_words[$rightarray[$i]-1]." "; 
            if($rightarray[$i] eq 0)
	    {
		$french_side = "NULL";
	    }
	}
	
	if($eng_side eq "NULL")
	{
	    @null_array = split(/ /,$french_side);
	    for($k=0;$k<=$#null_array;$k++)
	    {
		print "NULL -> $null_array[$k]\n";
	    }
	}

        elsif($french_side eq "NULL")
	{
	    @null_array = split(/ /,$eng_side);
	    for($k=0;$k<=$#null_array;$k++)
	    {
		print "$null_array[$k] -> NULL\n";
	    }
	}
	else
	{
            $eng_side = &removeSpaces($eng_side);
	    $french_side = &removeSpaces($french_side);
	    print "$eng_side -> $french_side\n";
	}
         
        $#null_array = 0;
        $#leftarray = 0;
        $#rightarray =0;

        if(defined($eng_side))
	{
	    undef($eng_side);
	}
        if(defined ($french_side))
	{
	    undef($french_side);
	}

    }

    @eng_words = ();
    @french_words = ();
    %reverse_hash = ();
   

}
# ---------------------------------------------------------------------------
#                                 USER DEFINED FUNCTIONS
# ---------------------------------------------------------------------------

# prints what are the command line options for the program and explain what
# input is required by different arguments
sub printHelp{

    &printUsage();
    print "OPTIONS:";
    print "\n\n  --version     Prints the version number";
    print "\n\n  --help        Prints the help message\n";
}



# prints the usage of the program.
sub printUsage{

    print "\nUsage:token.pl [ { --help | --version } SOURCE TARGET CONSENSUS_DIR ]";
    print "\nSOURCE - English text";
    print "\nTARGET - French text";
    print "\nCOSENSUS_DIR - direcotry where consensus files are present\n\n";
}




# prints the version number and copyright information.
sub printVersion{

    print "token.pl -  Version 0.2\n";
    print "Copyright (C) 2001-2002, Ted Pedersen & Nitin Varma\n";
}

#remove whiteSpaces    
sub removeSpaces{
    my $line = $_[0];
    $line =~ s/^\s+//;
    $line =~ s/\s+$//;
    $line =~ s/\s+/ /;
    $line =~ s/\n+//;
    return($line);
}
