#!/usr/local/bin/perl

# type.pl - version 0.2

# This program takes as input the file (output of token.pl). This file
# has token based gold data. This program prepares a type based gold data
# using the token based gold data.

# Copyright (C) 2001-2002.
# Ted Perdersen, University Of Minnesota, Duluth.
# tpederse@d.umn.edu
# Nitin Varma, University Of Minnesota, Duluth.
# varm0003@d.umn.edu


# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# package required for command line options
use Getopt::Long;

GetOptions("version", "help");

# Now strip the command line options

if ( defined $opt_help ) { $help = $opt_help; }
else                     { $help = 0; }


if ( defined $opt_version ) { $version = $opt_version; }
else                        { $version = 0; } 


# if asked for help, print the help and exit.  
if ( $help )
{
    &printHelp();
    exit;
}

# if asked for version, print the version number and exit
if ( $version )
{
    &printVersion();
    exit;
}

# check if all 3 non-optional arguments are provided or not.
if($#ARGV < 1 )
{
    
    &printUsage();
    exit;
}


$inputFile = shift;
$outputFile = shift;

# checks if the input file exists
  
  if( ! (-e $inputFile ) )
  {
      print "\nERROR!!! $inputFile not found\n ";
      exit;
     
  }

# check if the output file exists and prompts the user
# before over-writing

 if( (-e $outputFile ) )
  {
       print "\n$outputFile exists !!!  ";
       print "\nDo you want to overwrite it (Y/N)?";
       $ans = <STDIN>;
       chomp $ans;
       $ans = uc $ans;
       if($ans ne "Y")
       {
	   exit;
       }
     
  }

open(INPUT, $inputFile);
open(OUTPUT, ">$outputFile");

while($line = <INPUT>)
{
    $line =~ s/^\s+//;
    $line =~ s/\s+$//;
    $line =~ s/\s+/ /;
    $line =~ tr/A-Z/a-z/;
    $typeHash{$line}++
}

foreach $match(sort keys %typeHash)
{
    print OUTPUT "$match\n";
}


# ---------------------------------------------------------------------------
#                                 USER DEFINED FUNCTIONS
# ---------------------------------------------------------------------------

# prints what are the command line options for the program and explain what
# input is required by different arguments
sub printHelp{

    &printUsage();
    print "OPTIONS:";
    print "\n\n  --version     Prints the version number";
    print "\n\n  --help        Prints the help message\n";
}



# prints the usage of the program.
sub printUsage{

 print "Usage:type.pl [ { --help | --version } INPUT OUTPUT ]\n";
 print "\nINPUT : is the output file of token.pl containing token based";
 print "\ngold data.";
 print "\n\nOUTPUT: is the name of the file where type based gold data i.e.";
 print "\noutput of this program.\n";
}




# prints the version number and copyright information.
sub printVersion{

    print "type.pl -  Version 0.2\n";
    print "Copyright (C) 2001-2002, Ted Pedersen & Nitin Varma\n";

}

 
