#!/usr/local/bin/perl -w

# ensemble.pl - version 0.2


# Copyright (C) 2001-2002.
# Ted Perdersen, University Of Minnesota, Duluth.
# tpederse@d.umn.edu
# Nitin Varma, University Of Minnesota, Duluth.
# varm0003@d.umn.edu


# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# ----------------------------------------------------------------------------
#                             Main Program
# ----------------------------------------------------------------------------

# package required for command line options

use Getopt::Long;
GetOptions ("version","help","votes=i" );

if ( defined $opt_help ) { $help = $opt_help; }
else                     { $help = 0; }


if ( defined $opt_version ) { $version = $opt_version; }
else                        { $version = 0; } 

if (defined $opt_votes ) { $num_votes = $opt_votes;}
else                     { $num_votes = 1;}                         

# if asked for help, print the help and exit.  
if ( $help )
{
    &printHelp();
    exit;
}

# if asked for version, print the version number and exit
if ( $version )
{
    &printVersion();
    exit;
}

if($#ARGV < 1)
{
     &printUsage();
    exit;
}


$file_no = 0;

for($i=0; $i <= $#ARGV;$i++)
{
    $file_no++;
    $files[$i] = $ARGV[$i];
}


if($num_votes > $file_no)
{
    print "\nError!!! Number of votes should be less than or equal to the number of input files\n\n";
    exit;
}
  
foreach $file(@files)
{
   
    open(FILE, $file);
    
    $first_line = <FILE>;
    while($line = <FILE>)
    {
	$line =~ s/^\s+//;
	$line =~ s/\s+$//;
	$line =~ s/\s+/ /;
	$line =~ s/\n+//;   
	($words, $rest) = split(/ /, $line);
	$rest = "";
	$words =~ s/<>/ /g;
	($word1, $word2) = split(/ /,$words); 
	$pair = $word1."<>".$word2."<>"." ";  
	$hash{$pair}++;
	}

    }
    close(FILE);

chomp($first_line);
print "$first_line";
foreach $word_pair(keys %hash)
{

    if($hash{$word_pair} >= $num_votes )
    {
        $word_pair =~ s/^\s+//;
	$word_pair =~ s/\s+$//;
	$word_pair =~ s/\s+/ /;
	$word_pair =~ s/\n+//;
       	print "\n$word_pair";
     }
}
print "\n";

# ---------------------------------------------------------------------------
#                                 USER DEFINED FUNCTIONS
# ---------------------------------------------------------------------------

# prints what are the command line options for the program and explain what
# input is required by different arguments
sub printHelp{

    &printUsage();
    print "\n\nOPTIONS:";
    print "\n\n  --version     Prints the version number";
    print "\n\n  --help        Prints the help message";
    print "\n\n  --votes N     N is the number of files the word pairs need to be present";
    print "\n                to be considered as a valid translation pair.\n";
 
}



# prints the usage of the program.
sub printUsage{

 print "\nUsage:perl ensemble.pl [file1 file2{file3, file4...}]{--help|--version|--votes}";
 print "\n\nfile1, file2 ... are the output files of statisitc.pl\n";
}




# prints the version number and copyright information.
sub printVersion{

    print "ensemble.pl -  Version 0.2\n";
    print "Copyright (C) 2001-2002, Ted Pedersen & Nitin Varma\n";

}


